@@ -2,9 +2,10 @@ from typing import Dict, List
 import click
 from docker import APIClient, errors
 from rich import print
-client: APIClient = None
 
 
+client: APIClient = None
+
 
 def count_environents() -> int:
     return len(get_list_environments())
@@ -14,6 +15,8 @@ def get_list_environments() -> List[Dict]:
     environment_list = []
     client = APIClient(base_url="unix://var/run/docker.sock")
     environment_list = client.containers(all=True,filters={"label": "maintainer=Raiyan Yahya <raiyanyahyadeveloper@gmail.com>"})
+    custom_environment_list = client.containers(all=True,filters={"label": "Custom Environment"})
+    environment_list = environment_list + custom_environment_list
     return environment_list
 
 
